import { awsExpectUnion as __expectUnion, loadRestJsonErrorCode, parseJsonBody as parseBody, parseJsonErrorBody as parseErrorBody, } from "@aws-sdk/core";
import { requestBuilder as rb } from "@smithy/core";
import { _json, collectBody, decorateServiceException as __decorateServiceException, expectBoolean as __expectBoolean, expectInt32 as __expectInt32, expectNonNull as __expectNonNull, expectNumber as __expectNumber, expectObject as __expectObject, expectString as __expectString, limitedParseDouble as __limitedParseDouble, limitedParseFloat32 as __limitedParseFloat32, map, parseEpochTimestamp as __parseEpochTimestamp, parseRfc3339DateTimeWithOffset as __parseRfc3339DateTimeWithOffset, serializeFloat as __serializeFloat, take, withBaseException, } from "@smithy/smithy-client";
import { v4 as generateIdempotencyToken } from "uuid";
import { AccessDeniedException, AreaOfInterest, AreaOfInterestGeometry, ConflictException, InternalServerException, JobConfigInput, Property, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException, } from "../models/models_0";
import { SageMakerGeospatialServiceException as __BaseException } from "../models/SageMakerGeospatialServiceException";
export const se_DeleteEarthObservationJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/earth-observation-jobs/{Arn}");
    b.p("Arn", () => input.Arn, "{Arn}", false);
    let body;
    b.m("DELETE").h(headers).b(body);
    return b.build();
};
export const se_DeleteVectorEnrichmentJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/vector-enrichment-jobs/{Arn}");
    b.p("Arn", () => input.Arn, "{Arn}", false);
    let body;
    b.m("DELETE").h(headers).b(body);
    return b.build();
};
export const se_ExportEarthObservationJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/export-earth-observation-job");
    let body;
    body = JSON.stringify(take(input, {
        Arn: [],
        ClientToken: [true, (_) => _ ?? generateIdempotencyToken()],
        ExecutionRoleArn: [],
        ExportSourceImages: [],
        OutputConfig: (_) => _json(_),
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_ExportVectorEnrichmentJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/export-vector-enrichment-jobs");
    let body;
    body = JSON.stringify(take(input, {
        Arn: [],
        ClientToken: [true, (_) => _ ?? generateIdempotencyToken()],
        ExecutionRoleArn: [],
        OutputConfig: (_) => _json(_),
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_GetEarthObservationJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/earth-observation-jobs/{Arn}");
    b.p("Arn", () => input.Arn, "{Arn}", false);
    let body;
    b.m("GET").h(headers).b(body);
    return b.build();
};
export const se_GetRasterDataCollectionCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/raster-data-collection/{Arn}");
    b.p("Arn", () => input.Arn, "{Arn}", false);
    let body;
    b.m("GET").h(headers).b(body);
    return b.build();
};
export const se_GetTileCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/tile/{z}/{x}/{y}");
    b.p("x", () => input.x.toString(), "{x}", false);
    b.p("y", () => input.y.toString(), "{y}", false);
    b.p("z", () => input.z.toString(), "{z}", false);
    const query = map({
        [_IA]: [
            __expectNonNull(input.ImageAssets, `ImageAssets`) != null,
            () => (input[_IA] || []).map((_entry) => _entry),
        ],
        [_T]: [, __expectNonNull(input[_T], `Target`)],
        [_A]: [, __expectNonNull(input[_A], `Arn`)],
        [_IM]: [() => input.ImageMask !== void 0, () => input[_IM].toString()],
        [_OF]: [, input[_OF]],
        [_TRF]: [, input[_TRF]],
        [_PF]: [, input[_PF]],
        [_ODT]: [, input[_ODT]],
        [_ERA]: [, input[_ERA]],
    });
    let body;
    b.m("GET").h(headers).q(query).b(body);
    return b.build();
};
export const se_GetVectorEnrichmentJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/vector-enrichment-jobs/{Arn}");
    b.p("Arn", () => input.Arn, "{Arn}", false);
    let body;
    b.m("GET").h(headers).b(body);
    return b.build();
};
export const se_ListEarthObservationJobsCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/list-earth-observation-jobs");
    let body;
    body = JSON.stringify(take(input, {
        MaxResults: [],
        NextToken: [],
        SortBy: [],
        SortOrder: [],
        StatusEquals: [],
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_ListRasterDataCollectionsCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/raster-data-collections");
    const query = map({
        [_NT]: [, input[_NT]],
        [_MR]: [() => input.MaxResults !== void 0, () => input[_MR].toString()],
    });
    let body;
    b.m("GET").h(headers).q(query).b(body);
    return b.build();
};
export const se_ListTagsForResourceCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/tags/{ResourceArn}");
    b.p("ResourceArn", () => input.ResourceArn, "{ResourceArn}", false);
    let body;
    b.m("GET").h(headers).b(body);
    return b.build();
};
export const se_ListVectorEnrichmentJobsCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/list-vector-enrichment-jobs");
    let body;
    body = JSON.stringify(take(input, {
        MaxResults: [],
        NextToken: [],
        SortBy: [],
        SortOrder: [],
        StatusEquals: [],
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_SearchRasterDataCollectionCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/search-raster-data-collection");
    let body;
    body = JSON.stringify(take(input, {
        Arn: [],
        NextToken: [],
        RasterDataCollectionQuery: (_) => se_RasterDataCollectionQueryWithBandFilterInput(_, context),
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_StartEarthObservationJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/earth-observation-jobs");
    let body;
    body = JSON.stringify(take(input, {
        ClientToken: [true, (_) => _ ?? generateIdempotencyToken()],
        ExecutionRoleArn: [],
        InputConfig: (_) => se_InputConfigInput(_, context),
        JobConfig: (_) => se_JobConfigInput(_, context),
        KmsKeyId: [],
        Name: [],
        Tags: (_) => _json(_),
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_StartVectorEnrichmentJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/vector-enrichment-jobs");
    let body;
    body = JSON.stringify(take(input, {
        ClientToken: [true, (_) => _ ?? generateIdempotencyToken()],
        ExecutionRoleArn: [],
        InputConfig: (_) => _json(_),
        JobConfig: (_) => _json(_),
        KmsKeyId: [],
        Name: [],
        Tags: (_) => _json(_),
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_StopEarthObservationJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/earth-observation-jobs/stop");
    let body;
    body = JSON.stringify(take(input, {
        Arn: [],
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_StopVectorEnrichmentJobCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/vector-enrichment-jobs/stop");
    let body;
    body = JSON.stringify(take(input, {
        Arn: [],
    }));
    b.m("POST").h(headers).b(body);
    return b.build();
};
export const se_TagResourceCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {
        "content-type": "application/json",
    };
    b.bp("/tags/{ResourceArn}");
    b.p("ResourceArn", () => input.ResourceArn, "{ResourceArn}", false);
    let body;
    body = JSON.stringify(take(input, {
        Tags: (_) => _json(_),
    }));
    b.m("PUT").h(headers).b(body);
    return b.build();
};
export const se_UntagResourceCommand = async (input, context) => {
    const b = rb(input, context);
    const headers = {};
    b.bp("/tags/{ResourceArn}");
    b.p("ResourceArn", () => input.ResourceArn, "{ResourceArn}", false);
    const query = map({
        [_tK]: [
            __expectNonNull(input.TagKeys, `TagKeys`) != null,
            () => (input[_TK] || []).map((_entry) => _entry),
        ],
    });
    let body;
    b.m("DELETE").h(headers).q(query).b(body);
    return b.build();
};
export const de_DeleteEarthObservationJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
export const de_DeleteVectorEnrichmentJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
export const de_ExportEarthObservationJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        ExecutionRoleArn: __expectString,
        ExportSourceImages: __expectBoolean,
        ExportStatus: __expectString,
        OutputConfig: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_ExportVectorEnrichmentJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        ExecutionRoleArn: __expectString,
        ExportStatus: __expectString,
        OutputConfig: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_GetEarthObservationJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        ErrorDetails: _json,
        ExecutionRoleArn: __expectString,
        ExportErrorDetails: _json,
        ExportStatus: __expectString,
        InputConfig: (_) => de_InputConfigOutput(_, context),
        JobConfig: (_) => de_JobConfigInput(__expectUnion(_), context),
        KmsKeyId: __expectString,
        Name: __expectString,
        OutputBands: _json,
        Status: __expectString,
        Tags: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_GetRasterDataCollectionCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        Description: __expectString,
        DescriptionPageUrl: __expectString,
        ImageSourceBands: _json,
        Name: __expectString,
        SupportedFilters: (_) => de_FilterList(_, context),
        Tags: _json,
        Type: __expectString,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_GetTileCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = output.body;
    context.sdkStreamMixin(data);
    contents.BinaryFile = data;
    return contents;
};
export const de_GetVectorEnrichmentJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        ErrorDetails: _json,
        ExecutionRoleArn: __expectString,
        ExportErrorDetails: _json,
        ExportStatus: __expectString,
        InputConfig: _json,
        JobConfig: (_) => _json(__expectUnion(_)),
        KmsKeyId: __expectString,
        Name: __expectString,
        Status: __expectString,
        Tags: _json,
        Type: __expectString,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_ListEarthObservationJobsCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        EarthObservationJobSummaries: (_) => de_EarthObservationJobList(_, context),
        NextToken: __expectString,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_ListRasterDataCollectionsCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        NextToken: __expectString,
        RasterDataCollectionSummaries: (_) => de_DataCollectionsList(_, context),
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_ListTagsForResourceCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Tags: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_ListVectorEnrichmentJobsCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        NextToken: __expectString,
        VectorEnrichmentJobSummaries: (_) => de_VectorEnrichmentJobList(_, context),
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_SearchRasterDataCollectionCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        ApproximateResultCount: __expectInt32,
        Items: (_) => de_ItemSourceList(_, context),
        NextToken: __expectString,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_StartEarthObservationJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        ExecutionRoleArn: __expectString,
        InputConfig: (_) => de_InputConfigOutput(_, context),
        JobConfig: (_) => de_JobConfigInput(__expectUnion(_), context),
        KmsKeyId: __expectString,
        Name: __expectString,
        Status: __expectString,
        Tags: _json,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_StartVectorEnrichmentJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    const data = __expectNonNull(__expectObject(await parseBody(output.body, context)), "body");
    const doc = take(data, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        ExecutionRoleArn: __expectString,
        InputConfig: _json,
        JobConfig: (_) => _json(__expectUnion(_)),
        KmsKeyId: __expectString,
        Name: __expectString,
        Status: __expectString,
        Tags: _json,
        Type: __expectString,
    });
    Object.assign(contents, doc);
    return contents;
};
export const de_StopEarthObservationJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
export const de_StopVectorEnrichmentJobCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
export const de_TagResourceCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
export const de_UntagResourceCommand = async (output, context) => {
    if (output.statusCode !== 200 && output.statusCode >= 300) {
        return de_CommandError(output, context);
    }
    const contents = map({
        $metadata: deserializeMetadata(output),
    });
    await collectBody(output.body, context);
    return contents;
};
const de_CommandError = async (output, context) => {
    const parsedOutput = {
        ...output,
        body: await parseErrorBody(output.body, context),
    };
    const errorCode = loadRestJsonErrorCode(output, parsedOutput.body);
    switch (errorCode) {
        case "AccessDeniedException":
        case "com.amazonaws.sagemakergeospatial#AccessDeniedException":
            throw await de_AccessDeniedExceptionRes(parsedOutput, context);
        case "ConflictException":
        case "com.amazonaws.sagemakergeospatial#ConflictException":
            throw await de_ConflictExceptionRes(parsedOutput, context);
        case "InternalServerException":
        case "com.amazonaws.sagemakergeospatial#InternalServerException":
            throw await de_InternalServerExceptionRes(parsedOutput, context);
        case "ResourceNotFoundException":
        case "com.amazonaws.sagemakergeospatial#ResourceNotFoundException":
            throw await de_ResourceNotFoundExceptionRes(parsedOutput, context);
        case "ThrottlingException":
        case "com.amazonaws.sagemakergeospatial#ThrottlingException":
            throw await de_ThrottlingExceptionRes(parsedOutput, context);
        case "ValidationException":
        case "com.amazonaws.sagemakergeospatial#ValidationException":
            throw await de_ValidationExceptionRes(parsedOutput, context);
        case "ServiceQuotaExceededException":
        case "com.amazonaws.sagemakergeospatial#ServiceQuotaExceededException":
            throw await de_ServiceQuotaExceededExceptionRes(parsedOutput, context);
        default:
            const parsedBody = parsedOutput.body;
            return throwDefaultError({
                output,
                parsedBody,
                errorCode,
            });
    }
};
const throwDefaultError = withBaseException(__BaseException);
const de_AccessDeniedExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new AccessDeniedException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_ConflictExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new ConflictException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_InternalServerExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new InternalServerException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_ResourceNotFoundExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new ResourceNotFoundException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_ServiceQuotaExceededExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new ServiceQuotaExceededException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_ThrottlingExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new ThrottlingException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const de_ValidationExceptionRes = async (parsedOutput, context) => {
    const contents = map({});
    const data = parsedOutput.body;
    const doc = take(data, {
        Message: __expectString,
        ResourceId: __expectString,
    });
    Object.assign(contents, doc);
    const exception = new ValidationException({
        $metadata: deserializeMetadata(parsedOutput),
        ...contents,
    });
    return __decorateServiceException(exception, parsedOutput.body);
};
const se_AreaOfInterest = (input, context) => {
    return AreaOfInterest.visit(input, {
        AreaOfInterestGeometry: (value) => ({ AreaOfInterestGeometry: se_AreaOfInterestGeometry(value, context) }),
        _: (name, value) => ({ name: value }),
    });
};
const se_AreaOfInterestGeometry = (input, context) => {
    return AreaOfInterestGeometry.visit(input, {
        MultiPolygonGeometry: (value) => ({ MultiPolygonGeometry: se_MultiPolygonGeometryInput(value, context) }),
        PolygonGeometry: (value) => ({ PolygonGeometry: se_PolygonGeometryInput(value, context) }),
        _: (name, value) => ({ name: value }),
    });
};
const se_EoCloudCoverInput = (input, context) => {
    return take(input, {
        LowerBound: __serializeFloat,
        UpperBound: __serializeFloat,
    });
};
const se_InputConfigInput = (input, context) => {
    return take(input, {
        PreviousEarthObservationJobArn: [],
        RasterDataCollectionQuery: (_) => se_RasterDataCollectionQueryInput(_, context),
    });
};
const se_JobConfigInput = (input, context) => {
    return JobConfigInput.visit(input, {
        BandMathConfig: (value) => ({ BandMathConfig: _json(value) }),
        CloudMaskingConfig: (value) => ({ CloudMaskingConfig: _json(value) }),
        CloudRemovalConfig: (value) => ({ CloudRemovalConfig: _json(value) }),
        GeoMosaicConfig: (value) => ({ GeoMosaicConfig: _json(value) }),
        LandCoverSegmentationConfig: (value) => ({ LandCoverSegmentationConfig: _json(value) }),
        ResamplingConfig: (value) => ({ ResamplingConfig: se_ResamplingConfigInput(value, context) }),
        StackConfig: (value) => ({ StackConfig: se_StackConfigInput(value, context) }),
        TemporalStatisticsConfig: (value) => ({ TemporalStatisticsConfig: _json(value) }),
        ZonalStatisticsConfig: (value) => ({ ZonalStatisticsConfig: _json(value) }),
        _: (name, value) => ({ name: value }),
    });
};
const se_LandsatCloudCoverLandInput = (input, context) => {
    return take(input, {
        LowerBound: __serializeFloat,
        UpperBound: __serializeFloat,
    });
};
const se_LinearRing = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return se_Position(entry, context);
    });
};
const se_LinearRings = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return se_LinearRing(entry, context);
    });
};
const se_LinearRingsList = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return se_LinearRings(entry, context);
    });
};
const se_MultiPolygonGeometryInput = (input, context) => {
    return take(input, {
        Coordinates: (_) => se_LinearRingsList(_, context),
    });
};
const se_OutputResolutionResamplingInput = (input, context) => {
    return take(input, {
        UserDefined: (_) => se_UserDefined(_, context),
    });
};
const se_OutputResolutionStackInput = (input, context) => {
    return take(input, {
        Predefined: [],
        UserDefined: (_) => se_UserDefined(_, context),
    });
};
const se_PolygonGeometryInput = (input, context) => {
    return take(input, {
        Coordinates: (_) => se_LinearRings(_, context),
    });
};
const se_Position = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return __serializeFloat(entry);
    });
};
const se_Property = (input, context) => {
    return Property.visit(input, {
        EoCloudCover: (value) => ({ EoCloudCover: se_EoCloudCoverInput(value, context) }),
        LandsatCloudCoverLand: (value) => ({ LandsatCloudCoverLand: se_LandsatCloudCoverLandInput(value, context) }),
        Platform: (value) => ({ Platform: _json(value) }),
        ViewOffNadir: (value) => ({ ViewOffNadir: se_ViewOffNadirInput(value, context) }),
        ViewSunAzimuth: (value) => ({ ViewSunAzimuth: se_ViewSunAzimuthInput(value, context) }),
        ViewSunElevation: (value) => ({ ViewSunElevation: se_ViewSunElevationInput(value, context) }),
        _: (name, value) => ({ name: value }),
    });
};
const se_PropertyFilter = (input, context) => {
    return take(input, {
        Property: (_) => se_Property(_, context),
    });
};
const se_PropertyFilters = (input, context) => {
    return take(input, {
        LogicalOperator: [],
        Properties: (_) => se_PropertyFiltersList(_, context),
    });
};
const se_PropertyFiltersList = (input, context) => {
    return input
        .filter((e) => e != null)
        .map((entry) => {
        return se_PropertyFilter(entry, context);
    });
};
const se_RasterDataCollectionQueryInput = (input, context) => {
    return take(input, {
        AreaOfInterest: (_) => se_AreaOfInterest(_, context),
        PropertyFilters: (_) => se_PropertyFilters(_, context),
        RasterDataCollectionArn: [],
        TimeRangeFilter: (_) => se_TimeRangeFilterInput(_, context),
    });
};
const se_RasterDataCollectionQueryWithBandFilterInput = (input, context) => {
    return take(input, {
        AreaOfInterest: (_) => se_AreaOfInterest(_, context),
        BandFilter: _json,
        PropertyFilters: (_) => se_PropertyFilters(_, context),
        TimeRangeFilter: (_) => se_TimeRangeFilterInput(_, context),
    });
};
const se_ResamplingConfigInput = (input, context) => {
    return take(input, {
        AlgorithmName: [],
        OutputResolution: (_) => se_OutputResolutionResamplingInput(_, context),
        TargetBands: _json,
    });
};
const se_StackConfigInput = (input, context) => {
    return take(input, {
        OutputResolution: (_) => se_OutputResolutionStackInput(_, context),
        TargetBands: _json,
    });
};
const se_TimeRangeFilterInput = (input, context) => {
    return take(input, {
        EndTime: (_) => Math.round(_.getTime() / 1000),
        StartTime: (_) => Math.round(_.getTime() / 1000),
    });
};
const se_UserDefined = (input, context) => {
    return take(input, {
        Unit: [],
        Value: __serializeFloat,
    });
};
const se_ViewOffNadirInput = (input, context) => {
    return take(input, {
        LowerBound: __serializeFloat,
        UpperBound: __serializeFloat,
    });
};
const se_ViewSunAzimuthInput = (input, context) => {
    return take(input, {
        LowerBound: __serializeFloat,
        UpperBound: __serializeFloat,
    });
};
const se_ViewSunElevationInput = (input, context) => {
    return take(input, {
        LowerBound: __serializeFloat,
        UpperBound: __serializeFloat,
    });
};
const de_AreaOfInterest = (output, context) => {
    if (output.AreaOfInterestGeometry != null) {
        return {
            AreaOfInterestGeometry: de_AreaOfInterestGeometry(__expectUnion(output.AreaOfInterestGeometry), context),
        };
    }
    return { $unknown: Object.entries(output)[0] };
};
const de_AreaOfInterestGeometry = (output, context) => {
    if (output.MultiPolygonGeometry != null) {
        return {
            MultiPolygonGeometry: de_MultiPolygonGeometryInput(output.MultiPolygonGeometry, context),
        };
    }
    if (output.PolygonGeometry != null) {
        return {
            PolygonGeometry: de_PolygonGeometryInput(output.PolygonGeometry, context),
        };
    }
    return { $unknown: Object.entries(output)[0] };
};
const de_DataCollectionsList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_RasterDataCollectionMetadata(entry, context);
    });
    return retVal;
};
const de_EarthObservationJobList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_ListEarthObservationJobOutputConfig(entry, context);
    });
    return retVal;
};
const de_EoCloudCoverInput = (output, context) => {
    return take(output, {
        LowerBound: __limitedParseFloat32,
        UpperBound: __limitedParseFloat32,
    });
};
const de_Filter = (output, context) => {
    return take(output, {
        Maximum: __limitedParseFloat32,
        Minimum: __limitedParseFloat32,
        Name: __expectString,
        Type: __expectString,
    });
};
const de_FilterList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_Filter(entry, context);
    });
    return retVal;
};
const de_Geometry = (output, context) => {
    return take(output, {
        Coordinates: (_) => de_LinearRings(_, context),
        Type: __expectString,
    });
};
const de_InputConfigOutput = (output, context) => {
    return take(output, {
        PreviousEarthObservationJobArn: __expectString,
        RasterDataCollectionQuery: (_) => de_RasterDataCollectionQueryOutput(_, context),
    });
};
const de_ItemSource = (output, context) => {
    return take(output, {
        Assets: _json,
        DateTime: (_) => __expectNonNull(__parseEpochTimestamp(__expectNumber(_))),
        Geometry: (_) => de_Geometry(_, context),
        Id: __expectString,
        Properties: (_) => de_Properties(_, context),
    });
};
const de_ItemSourceList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_ItemSource(entry, context);
    });
    return retVal;
};
const de_JobConfigInput = (output, context) => {
    if (output.BandMathConfig != null) {
        return {
            BandMathConfig: _json(output.BandMathConfig),
        };
    }
    if (output.CloudMaskingConfig != null) {
        return {
            CloudMaskingConfig: _json(output.CloudMaskingConfig),
        };
    }
    if (output.CloudRemovalConfig != null) {
        return {
            CloudRemovalConfig: _json(output.CloudRemovalConfig),
        };
    }
    if (output.GeoMosaicConfig != null) {
        return {
            GeoMosaicConfig: _json(output.GeoMosaicConfig),
        };
    }
    if (output.LandCoverSegmentationConfig != null) {
        return {
            LandCoverSegmentationConfig: _json(output.LandCoverSegmentationConfig),
        };
    }
    if (output.ResamplingConfig != null) {
        return {
            ResamplingConfig: de_ResamplingConfigInput(output.ResamplingConfig, context),
        };
    }
    if (output.StackConfig != null) {
        return {
            StackConfig: de_StackConfigInput(output.StackConfig, context),
        };
    }
    if (output.TemporalStatisticsConfig != null) {
        return {
            TemporalStatisticsConfig: _json(output.TemporalStatisticsConfig),
        };
    }
    if (output.ZonalStatisticsConfig != null) {
        return {
            ZonalStatisticsConfig: _json(output.ZonalStatisticsConfig),
        };
    }
    return { $unknown: Object.entries(output)[0] };
};
const de_LandsatCloudCoverLandInput = (output, context) => {
    return take(output, {
        LowerBound: __limitedParseFloat32,
        UpperBound: __limitedParseFloat32,
    });
};
const de_LinearRing = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_Position(entry, context);
    });
    return retVal;
};
const de_LinearRings = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_LinearRing(entry, context);
    });
    return retVal;
};
const de_LinearRingsList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_LinearRings(entry, context);
    });
    return retVal;
};
const de_ListEarthObservationJobOutputConfig = (output, context) => {
    return take(output, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        Name: __expectString,
        OperationType: __expectString,
        Status: __expectString,
        Tags: _json,
    });
};
const de_ListVectorEnrichmentJobOutputConfig = (output, context) => {
    return take(output, {
        Arn: __expectString,
        CreationTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        DurationInSeconds: __expectInt32,
        Name: __expectString,
        Status: __expectString,
        Tags: _json,
        Type: __expectString,
    });
};
const de_MultiPolygonGeometryInput = (output, context) => {
    return take(output, {
        Coordinates: (_) => de_LinearRingsList(_, context),
    });
};
const de_OutputResolutionResamplingInput = (output, context) => {
    return take(output, {
        UserDefined: (_) => de_UserDefined(_, context),
    });
};
const de_OutputResolutionStackInput = (output, context) => {
    return take(output, {
        Predefined: __expectString,
        UserDefined: (_) => de_UserDefined(_, context),
    });
};
const de_PolygonGeometryInput = (output, context) => {
    return take(output, {
        Coordinates: (_) => de_LinearRings(_, context),
    });
};
const de_Position = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return __limitedParseDouble(entry);
    });
    return retVal;
};
const de_Properties = (output, context) => {
    return take(output, {
        EoCloudCover: __limitedParseFloat32,
        LandsatCloudCoverLand: __limitedParseFloat32,
        Platform: __expectString,
        ViewOffNadir: __limitedParseFloat32,
        ViewSunAzimuth: __limitedParseFloat32,
        ViewSunElevation: __limitedParseFloat32,
    });
};
const de_Property = (output, context) => {
    if (output.EoCloudCover != null) {
        return {
            EoCloudCover: de_EoCloudCoverInput(output.EoCloudCover, context),
        };
    }
    if (output.LandsatCloudCoverLand != null) {
        return {
            LandsatCloudCoverLand: de_LandsatCloudCoverLandInput(output.LandsatCloudCoverLand, context),
        };
    }
    if (output.Platform != null) {
        return {
            Platform: _json(output.Platform),
        };
    }
    if (output.ViewOffNadir != null) {
        return {
            ViewOffNadir: de_ViewOffNadirInput(output.ViewOffNadir, context),
        };
    }
    if (output.ViewSunAzimuth != null) {
        return {
            ViewSunAzimuth: de_ViewSunAzimuthInput(output.ViewSunAzimuth, context),
        };
    }
    if (output.ViewSunElevation != null) {
        return {
            ViewSunElevation: de_ViewSunElevationInput(output.ViewSunElevation, context),
        };
    }
    return { $unknown: Object.entries(output)[0] };
};
const de_PropertyFilter = (output, context) => {
    return take(output, {
        Property: (_) => de_Property(__expectUnion(_), context),
    });
};
const de_PropertyFilters = (output, context) => {
    return take(output, {
        LogicalOperator: __expectString,
        Properties: (_) => de_PropertyFiltersList(_, context),
    });
};
const de_PropertyFiltersList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_PropertyFilter(entry, context);
    });
    return retVal;
};
const de_RasterDataCollectionMetadata = (output, context) => {
    return take(output, {
        Arn: __expectString,
        Description: __expectString,
        DescriptionPageUrl: __expectString,
        Name: __expectString,
        SupportedFilters: (_) => de_FilterList(_, context),
        Tags: _json,
        Type: __expectString,
    });
};
const de_RasterDataCollectionQueryOutput = (output, context) => {
    return take(output, {
        AreaOfInterest: (_) => de_AreaOfInterest(__expectUnion(_), context),
        PropertyFilters: (_) => de_PropertyFilters(_, context),
        RasterDataCollectionArn: __expectString,
        RasterDataCollectionName: __expectString,
        TimeRangeFilter: (_) => de_TimeRangeFilterOutput(_, context),
    });
};
const de_ResamplingConfigInput = (output, context) => {
    return take(output, {
        AlgorithmName: __expectString,
        OutputResolution: (_) => de_OutputResolutionResamplingInput(_, context),
        TargetBands: _json,
    });
};
const de_StackConfigInput = (output, context) => {
    return take(output, {
        OutputResolution: (_) => de_OutputResolutionStackInput(_, context),
        TargetBands: _json,
    });
};
const de_TimeRangeFilterOutput = (output, context) => {
    return take(output, {
        EndTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
        StartTime: (_) => __expectNonNull(__parseRfc3339DateTimeWithOffset(_)),
    });
};
const de_UserDefined = (output, context) => {
    return take(output, {
        Unit: __expectString,
        Value: __limitedParseFloat32,
    });
};
const de_VectorEnrichmentJobList = (output, context) => {
    const retVal = (output || [])
        .filter((e) => e != null)
        .map((entry) => {
        return de_ListVectorEnrichmentJobOutputConfig(entry, context);
    });
    return retVal;
};
const de_ViewOffNadirInput = (output, context) => {
    return take(output, {
        LowerBound: __limitedParseFloat32,
        UpperBound: __limitedParseFloat32,
    });
};
const de_ViewSunAzimuthInput = (output, context) => {
    return take(output, {
        LowerBound: __limitedParseFloat32,
        UpperBound: __limitedParseFloat32,
    });
};
const de_ViewSunElevationInput = (output, context) => {
    return take(output, {
        LowerBound: __limitedParseFloat32,
        UpperBound: __limitedParseFloat32,
    });
};
const deserializeMetadata = (output) => ({
    httpStatusCode: output.statusCode,
    requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
    extendedRequestId: output.headers["x-amz-id-2"],
    cfId: output.headers["x-amz-cf-id"],
});
const collectBodyString = (streamBody, context) => collectBody(streamBody, context).then((body) => context.utf8Encoder(body));
const isSerializableHeaderValue = (value) => value !== undefined &&
    value !== null &&
    value !== "" &&
    (!Object.getOwnPropertyNames(value).includes("length") || value.length != 0) &&
    (!Object.getOwnPropertyNames(value).includes("size") || value.size != 0);
const _A = "Arn";
const _ERA = "ExecutionRoleArn";
const _IA = "ImageAssets";
const _IM = "ImageMask";
const _MR = "MaxResults";
const _NT = "NextToken";
const _ODT = "OutputDataType";
const _OF = "OutputFormat";
const _PF = "PropertyFilters";
const _T = "Target";
const _TK = "TagKeys";
const _TRF = "TimeRangeFilter";
const _tK = "tagKeys";
